==> trilinos-15.1.1.tar.gz: Trilinos-trilinos-release-15-1-1/packages/kokkos/core/unit_test/TestAtomicOperations_complexdouble.hpp <==
//@HEADER
// ************************************************************************
//
//                        Kokkos v. 4.0
//       Copyright (2022) National Technology & Engineering
//               Solutions of Sandia, LLC (NTESS).
//
// Under the terms of Contract DE-NA0003525 with NTESS,
// the U.S. Government retains certain rights in this software.
//
// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
// See https://kokkos.org/LICENSE for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//@HEADER

#include <TestAtomicOperations.hpp>

using namespace TestAtomicOperations;

namespace Test {
TEST(TEST_CATEGORY, atomic_operations_complexdouble) {
#if defined(KOKKOS_ENABLE_SYCL) && \
    !defined(KOKKOS_IMPL_SYCL_DEVICE_GLOBAL_SUPPORTED)
  if (std::is_same_v<TEST_EXECSPACE, Kokkos::Experimental::SYCL>)
    GTEST_SKIP() << "skipping since device_global variables are not available";
#endif
  const int start = -5;
  const int end   = 11;
  for (int i = start; i < end; ++i) {
    using T   = Kokkos::complex<double>;
    T old_val = static_cast<T>(i);
    T update  = static_cast<T>(end - i - start);
    ASSERT_TRUE(
        (atomic_op_test<AddAtomicTest, T, TEST_EXECSPACE>(old_val, update)));
    ASSERT_TRUE(
        (atomic_op_test<SubAtomicTest, T, TEST_EXECSPACE>(old_val, update)));
    ASSERT_TRUE(
        (atomic_op_test<MulAtomicTest, T, TEST_EXECSPACE>(old_val, update)));

    // FIXME_32BIT disable division test for 32bit where we have accuracy issues
    // with division atomics still compile it though
    if (sizeof(void*) == 8) {
      ASSERT_TRUE((update != 0
                       ? atomic_op_test<DivAtomicTest, T, TEST_EXECSPACE>(
                             old_val, update)
                       : true));
    }
    ASSERT_TRUE((atomic_op_test<LoadStoreAtomicTest, T, TEST_EXECSPACE>(
        old_val, update)));
  }
}
}  // namespace Test

==> trilinos_16.1.0.orig.tar.gz: Trilinos-trilinos-release-16-1-0/packages/kokkos/core/unit_test/TestAtomicOperations_complexdouble.hpp <==
//@HEADER
// ************************************************************************
//
//                        Kokkos v. 4.0
//       Copyright (2022) National Technology & Engineering
//               Solutions of Sandia, LLC (NTESS).
//
// Under the terms of Contract DE-NA0003525 with NTESS,
// the U.S. Government retains certain rights in this software.
//
// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
// See https://kokkos.org/LICENSE for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//@HEADER

#include <TestAtomicOperations.hpp>

using namespace TestAtomicOperations;

namespace Test {
TEST(TEST_CATEGORY, atomic_operations_complexdouble) {
#if defined(KOKKOS_ENABLE_SYCL) && \
    !defined(KOKKOS_IMPL_SYCL_DEVICE_GLOBAL_SUPPORTED)
  if (std::is_same_v<TEST_EXECSPACE, Kokkos::SYCL>)
    GTEST_SKIP() << "skipping since device_global variables are not available";
#endif
  const int start = -5;
  const int end   = 11;
  for (int i = start; i < end; ++i) {
    using T   = Kokkos::complex<double>;
    T old_val = static_cast<T>(i);
    T update  = static_cast<T>(end - i - start);
    ASSERT_TRUE(
        (atomic_op_test<AddAtomicTest, T, TEST_EXECSPACE>(old_val, update)));
    ASSERT_TRUE(
        (atomic_op_test<SubAtomicTest, T, TEST_EXECSPACE>(old_val, update)));
    ASSERT_TRUE(
        (atomic_op_test<MulAtomicTest, T, TEST_EXECSPACE>(old_val, update)));

    // FIXME_32BIT disable division test for 32bit where we have accuracy issues
    // with division atomics still compile it though
    if (sizeof(void*) == 8) {
      ASSERT_TRUE((update != 0
                       ? atomic_op_test<DivAtomicTest, T, TEST_EXECSPACE>(
                             old_val, update)
                       : true));
    }
    ASSERT_TRUE((atomic_op_test<LoadStoreAtomicTest, T, TEST_EXECSPACE>(
        old_val, update)));
  }
}
}  // namespace Test
